@@ -104,7 +104,7 @@ def find_coexistent_mu(
             mu = (mu_min + mu_max) / 2
         
         else: # interpolate
-            if iter > 2:
+            if iter >= 2:
                 mu1 = rec['mu'][-1]
                 omega_l_1 = rec['omega_l'][-1]
                 omega_s_1 = rec['omega_s'][-1]
@@ -160,6 +160,7 @@ def find_coexistent_mu(
         if verbose:
             console.log(f'omega_l={omega_l}')
             console.log(f'omega_s={omega_s}')
+            console.log(f'omega_l-omega_s={omega_l - omega_s}')
 
         if omega_s < omega_l:
             mu_min = mu
